import dropb
def addprofile(base,name,znac,autopush=True):
    open(f'{base}.txt', 'a+')
    fin = open(f"{base}.txt", "at")

    fin.write(f'{name} {str(znac)}\n')

    fin.close()
    if autopush==True:
        dropb.push_database(base)
    else:
        ...
def getbase(base):
    open(f'{base}.txt', 'a+')
    f = lambda A, n=2: [A[i:i + n] for i in range(0, len(A), n)]
    A = (open(f'{base}.txt','r').read()).split()
    a= ((f(A)))
    d = dict(a)
    return d
def addmoney(base,name,key,money,autopush=True):
    open(f'{base}.txt', 'a+')
    dic=getbase(base)

    money1=int(dic[name])
    if key=='+':
        dic[name]=str(int(money1)+int(money))
    else:
        dic[name]=str(int(money1)-int(money))
    dic=((list(dic.items())))
    ab=[]
    for i in range(len(dic)):
        ab.append(' '.join(list(dic[i])))
    dic='\n'.join(ab)
    f = open(f'{base}.txt', 'w')
    f.write(dic)
    f.close()
    if autopush==True:
        dropb.push_database(base)
    else:
        ...
def checkbase(base,name):
    open(f'{base}.txt', 'a+')

    dic = getbase(base)

    money1 = int(dic[name])
    return money1

def removeuser(base,name,autopush=True):
    open(f'{base}.txt', 'a+')
    text = open(f'{base}.txt', 'r').read()
    text = text.replace(f'{name} {str(checkbase(base, name))}', '', 1)
    f = open(f'{base}.txt', 'w')
    f.write(text)
    f.close()
    if autopush==True:
        dropb.push_database(base)
    else:
        ...
#Чтобы загрузить базу с сервера, используй функцию:
#get_database(Название базы)


import dropbox

dbx = dropbox.Dropbox(
    'sl.BLh6WeGcIj4jllx-UJiJQ4HZ7iNw3bHtLzvpnpEqmmUCp255KNoEINT100qdYPyZnF3WvRViFohZsf3xXVehzTDTOZdqeOkBL5peRPJOwgLyLY08Njb9JfFRN09D35GGvrZB5K17a6rl'
)
import os
def push_database(base):
    try:
      dbx.files_delete_v2(f'/{base}.txt')
    except:
        print(f'No such file or directory - {base}')
    with open(f'{base}.txt', 'rb') as file:  # открываем файл в режиме чтение побайтово
        response = dbx.files_upload(file.read(),
                                    f'/{base}.txt')  # загружаем файл: первый аргумент (file.read()) - какой файл; второй - название, которое будет присвоено файлу уже на дропбоксе.

def get_database(base):
    try:
        os.remove(f"base.txt")
    except:
        ...
    metadata, f = dbx.files_download('/' + base+'.txt')
    out = open(base+'.txt', 'wb')
    out.write(f.content)
    out.close()
push_database('data')


#!/usr/bin/env python

from distutils.core import setup

setup(name='dbss-anisimov',
      version='1.0',
      description='The best way to convert txt to docx using python',
      author='Nikita_Anisimov',
      author_email='qwerty111111333@mail.ru',
      url='https://github.com/Anisimov1123/txt2docx/blob/main/README.md?plain=1',
      packages=['dbss-anisimov'],
      install_requires=['dropbox']
     )